docs.rs failed to build rsfdisk-sys-0.2.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
rsfdisk-sys-0.2.1
rsfdisk-sys
Raw Rust FFI bindings to the util-linux/libfdisk C library.
Supported library version
This crate requires libfdisk version 2.39.2 or later.
Build dependencies
Install the following packages beforehand to build this crate:
util-linux: to generate Rust bindings fromlibfdisk's header files.libclang: to satisfy the dependency ofbindgenonlibclang.pkg-config: to detect system libraries.
This in addition to the Rust toolchain.
NixOS
Temporarily install the required packages with:
nix-shell -p util-linux.dev libclang.lib pkg-config
or permanently with:
nix-env -iA nixos.util-linux.dev nixos.libclang.lib nixos.pkg-config
Alpine Linux
As root, issue the following command:
apk add util-linux-dev clang-libclang pkgconfig
Ubuntu
sudo apt-get install libfdisk-dev libclang-dev pkg-config
License
Copyright (c) 2023 Nick Piaddo
SPDX-License-Identifier: Apache-2.0 OR MIT